from setuptools import setup, find_packages

setup(
    name="alsolib",
    version="0.7.5",
    author="asunc",
    author_email="3182305655@qq.com",
    packages=find_packages(),
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
)